% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/NbBvs_est.R
\name{NbBvs_est}
\alias{NbBvs_est}
\title{Negative Binomial regression model using SSVS approach for estimation}
\usage{
NbBvs_est(
  X = X,
  y = y,
  niter = 1e+06,
  burnin = 15000,
  n.thin = 10,
  rho = 0.5,
  h_a,
  h_b,
  k3 = 1,
  k4 = 1/5,
  lm0 = 100,
  lm = 1,
  r0 = 1000,
  order = NULL
)
}
\arguments{
\item{X}{Data frame of design matrix (not standardized) without the column corresponding to the intercept. All code assumes that an intercept will be included in each model and the variables without missing values are put in the front.}

\item{y}{Vector of response variables.}

\item{niter}{Number of MCMC iterations; defaults to 1e+06.}

\item{burnin}{Number of samples in burn-in; defaults to 15,000.}

\item{n.thin}{Thinning degree; defaults to n.thin = 10, i.e., we keep every 10th value.}

\item{rho}{Inclusion probability (same for all predictors); defaults to rho = 0.5 for discrete uniform.
If specified to NA (rho = NA), the Gibbs sampler will use Beta prior for rho.}

\item{k3}{Shape parameter for Gamma prior on precision for second level of the model for covariates; defauls to 1.}

\item{k4}{Rate parameter for Gamma prior on precision for second level of the model for covariates; defauls to 1/5.}

\item{lm0}{Prior variance for Normal prior on the intercept; defauls to 100.}

\item{lm}{Prior variance for Normal prior component for other regression coefficients; defauls to 1.}

\item{r0}{Upper limit for Uniform prior on NB dispersion parameter; defauls to 1000.}

\item{order}{Ordering of covariates; defaults to order = NULL for no user-specified ordering and determined by missing rate.}

\item{(h_a, h_b)}{Hyper-parameters of the alternative Beta prior for rho.}
}
\value{
A list containing the following components:
\itemize{
\item B.mean - posterior mean of the regression coefficients in the top level, ordered as described in Details.
\item B.median - posterior median of the regression coefficients in the top level, ordered as described in Details.
\item d.mean - posterior mean of the inclusion probabilities of all covariates, ordered as described in Details.
\item d.median - posterior median of the inclusion probabilities of all covariates, ordered as described in Details.
\item B.samples - MCMC samples from posterior predictive distribution of the regression coefficients as a matrix, ordered as described in Details.
\item order - ordering of covariates that is being used.
}
}
\description{
This function implements Negative Binomial regression model using SSVS approach with missing predictors via JAGS, for estimation.
}
\details{
This function implements SSVS approach in Negative Binomial regression model with missing predictors for estimation. The MCMC samples from posterior predictive distribution of the regression coefficients in the top level
are also returned so that the user may compute lower and upper percentiles to obtain the posterior credible intervals.

The ordering of covariates is going to have an impact on the joint distribution in the second level as the covariates may not be fully observed.
If not specified by the user, this function by default orders variables by the percentage of missing values so that variables with the least missing values appear first.

For the choice of the hyper-parameters (h_a, h_b) of the alternative Beta prior for rho, \insertCite{Li:2013;textual}{NbBvs} recommends (h_a=1, h_b=p^c) for higher dimensional cases, where c takes value between 0 and 1. More discussion could be found in \insertCite{Scot:Berg:2010;textual}{NbBvs}.
}
\examples{
########################################################
########################################################
## The code below can be used to generate one dataset ##
## under scenario 1 of the simulation from            ##
## Section 4.4 of Li, Ghosh, and Villarini            ##
########################################################
########################################################
set.seed(13)
library(mvtnorm)
sig <- matrix(0,12,12)
diag(sig) <- 0.5
for (i in 1:12) {sig[i,i] <- 1}
sig[1,2] <- 0.7;  sig[2,1] <- 0.7 # sst obs atl and trop
sig[1,3] <- 0.9; sig[3,1] <- 0.9 # sst obs atl and gfdla atl
sig[1,4] <- 0.7; sig[4,1] <- 0.7 # sst obs atl and gfdla trop
sig[2,4] <- 0.7; sig[4,2] <- 0.7 # sst obs trop and gfdla trop
sig[3,4] <- 0.7; sig[4,3] <- 0.7 # gfdla atl and gfdla trop
sig[2,3] <- 0.6; sig[3,2] <- 0.6 # sst obs trop and gfdla atl
X <- rmvnorm(n=100,mean=rep(0,12),sigma=sig)
mu.pois <- exp(cbind(1,X[,1:4])\%*\%c(1.8,0.4,-0.2,0.35,-0.25))
y <- rpois(n=100,lambda=mu.pois)

X.miss <- X
X.miss[51:100, 1:2] <- NA # X1 and X2 are unavailable for the last 50 observations
##################################################
########### Method 1 (Retain/Impute) #############
##################################################
system.time(sim1 <- NbBvs_est(X = X.miss, y = y, niter = 100000, burnin = 20000,
  n.thin = 10, rho = 0.5))

B.est.m1 <- sim1$B.mean[sim1$order]
B.inc.m1 <- sim1$d.mean[sim1$order]

############################################
########### Method 2 (Discard) #############
############################################
system.time(sim2 <- NbBvs_est(X = X[, 3:12], y = y, niter = 100000, burnin = 20000,
  n.thin = 10, rho = 0.5))

B.est.m2 <- sim2$B.mean[sim2$order]
B.inc.m2 <- sim2$d.mean[sim2$order]

Note: this example is included for illustrative purposes.
For more details, please refer to Li, Ghosh, and Villarini.

}
\references{
\insertRef{Scot:Berg:2010}{NbBvs}

\insertRef{Li:2013}{NbBvs}
}
