% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/NbBvs_pred.R
\name{NbBvs_pred}
\alias{NbBvs_pred}
\title{Negative Binomial regression model using SSVS approach for prediction}
\usage{
NbBvs_pred(
  d,
  X = X,
  y = y,
  niter = 1e+06,
  burnin = 15000,
  n.thin = 10,
  rho = 0.5,
  h_a,
  h_b,
  k3 = 1,
  k4 = 1/5,
  lm0 = 100,
  lm = 1,
  r0 = 1000,
  impute = TRUE,
  order = NULL
)
}
\arguments{
\item{d}{Index of rows on which the response is predicted.}

\item{X}{Data frame of design matrix (not standardized) without the column corresponding to the intercept. All code assumes that an intercept will be included in each model and the variables without missing values are put in the front.}

\item{y}{Vector of response variables.}

\item{niter}{Number of MCMC iterations; defaults to 1e+06.}

\item{burnin}{Number of samples in burn-in; defaults to 15,000.}

\item{n.thin}{Thinning degree; defaults to n.thin = 10, i.e., we keep every 10th value.}

\item{rho}{Inclusion probability (same for all predictors); defaults to rho = 0.5 for discrete uniform.
If specified to NA (rho = NA), the Gibbs sampler will use Beta prior for rho.}

\item{k3}{Shape parameter for Gamma prior on precision for second level of the model for covariates; defauls to 1.}

\item{k4}{Rate parameter for Gamma prior on precision for second level of the model for covariates; defauls to 1/5.}

\item{lm0}{Prior variance for Normal prior on the intercept; defauls to 100.}

\item{lm}{Prior variance for Normal prior component for other regression coefficients; defauls to 1.}

\item{r0}{Upper limit for Uniform prior on NB dispersion parameter; defauls to 1000.}

\item{impute}{Indicator for whether to sample covariate values from posterior predictive distribution when covariate values are unavailable at time of prediction; defaults to TRUE.}

\item{order}{Ordering of covariates; defaults to order = NULL for no user-specified ordering and determined by missing rate.}

\item{(h_a, h_b)}{Hyper-parameters of the alternative Beta prior for rho.}
}
\value{
MCMC samples from posterior predictive distribution of y as a matrix.
}
\description{
This function implements Negative Binomial regression model using SSVS approach with missing predictors via JAGS, for prediction.
}
\details{
This function implements SSVS approach in Negative Binomial regression model with missing predictors for prediction. If some of the covariates are missing/unobserved at the time of prediction, this function by default retain all covariates in the model; sample the unobserved covariates from their predictive distribution; and marginalize over them using Monte Carlo integration.

The ordering of covariates is going to have an impact on the joint distribution in the second level as the covariates may not be fully observed.

If not specified by the user, this function by default orders variables by the percentage of missing values so that variables with the least missing values appear first.

For the choice of the hyper-parameters (h_a, h_b) of the alternative Beta prior for rho, \insertCite{Li:2013;textual}{NbBvs} recommends (h_a=1, h_b=p^c) for higher dimensional cases, where c takes value between 0 and 1. More discussion could be found in \insertCite{Scot:Berg:2010;textual}{NbBvs}.
}
\examples{
#########################################################
#########################################################
## The code below can be used to generate and analyze  ##
## one dataset under scenario 1 of the simulation from ##
## Section 4.4 of Li, Ghosh, and Villarini             ##
#########################################################
#########################################################
set.seed(13)
library(mvtnorm)
library(mcmcse)
sig <- matrix(0,12,12)
diag(sig) <- 0.5
for (i in 1:12) {sig[i,i] <- 1}
sig[1,2] <- 0.7;  sig[2,1] <- 0.7 # sst obs atl and trop
sig[1,3] <- 0.9; sig[3,1] <- 0.9 # sst obs atl and gfdla atl
sig[1,4] <- 0.7; sig[4,1] <- 0.7 # sst obs atl and gfdla trop
sig[2,4] <- 0.7; sig[4,2] <- 0.7 # sst obs trop and gfdla trop
sig[3,4] <- 0.7; sig[4,3] <- 0.7 # gfdla atl and gfdla trop
sig[2,3] <- 0.6; sig[3,2] <- 0.6 # sst obs trop and gfdla atl
X <- rmvnorm(n=100,mean=rep(0,12),sigma=sig)
mu.pois <- exp(cbind(1,X[,1:4])\%*\%c(1.8,0.4,-0.2,0.35,-0.25))
y <- rpois(n=100,lambda=mu.pois)

true.y.pred <- y[51:100] # Store the actual values of y which will be predicted
X.miss <- X
X.miss[51:100, 1:2] <- NA # X1 and X2 are unavailable for the last 50 observations

##################################################
########### Method 1 (Retain/Impute) #############
##################################################

system.time(sim1 <- NbBvs_pred(d=c(51:100), X = X.miss, y = y, niter = 100000, burnin = 20000,
n.thin = 10, rho = 0.5, impute = TRUE))

med <- apply(sim1,2,function(x){mcse.q(x,q=0.5)$est})
rmse <- sqrt(mean((med - true.y.pred)^2))
mae <- mean(abs(med - true.y.pred))
perc.5 <- apply(sim1,2,function(x){mcse.q(x,q=0.05)$est})
perc.95 <- apply(sim1,2,function(x){mcse.q(x,q=0.95)$est})
cov.equaltail <- mean(true.y.pred >= perc.5 & true.y.pred <= perc.95)
size.equaltail <- mean(perc.95 - perc.5 + 1)
cov.hpd <- mean(apply(rbind(true.y.pred,sim1),2,function(x){x[1]\%in\%emp.hpd(x[-1])}))
size.hpd <- mean(apply(sim1,2,function(x){length(emp.hpd(x))}))
cor.pearson <- cor(med,true.y.pred,method="pearson")
cor.spearman <- cor(med,true.y.pred,method="spearman")
scen1.m1 <- c(cor.pearson,cor.spearman,rmse,mae,cov.hpd,cov.equaltail,size.hpd,size.equaltail)

############################################
########### Method 2 (Discard) #############
############################################

system.time(sim2 <- NbBvs_pred(d=c(51:100), X = X.miss, y = y, niter = 100000, burnin = 20000,
n.thin = 10, rho = 0.5, impute = FALSE))

med <- apply(sim2,2,function(x){mcse.q(x,q=0.5)$est})
rmse <- sqrt(mean((med - true.y.pred)^2))
mae <- mean(abs(med - true.y.pred))
perc.5 <- apply(sim2,2,function(x){mcse.q(x,q=0.05)$est})
perc.95 <- apply(sim2,2,function(x){mcse.q(x,q=0.95)$est})
cov.equaltail <- mean(true.y.pred >= perc.5 & true.y.pred <= perc.95)
size.equaltail <- mean(perc.95 - perc.5 + 1)
cov.hpd <- mean(apply(rbind(true.y.pred,sim2),2,function(x){x[1]\%in\%emp.hpd(x[-1])}))
size.hpd <- mean(apply(sim2,2,function(x){length(emp.hpd(x))}))
cor.pearson <- cor(med,true.y.pred,method="pearson")
cor.spearman <- cor(med,true.y.pred,method="spearman")
scen1.m2 <- c(cor.pearson,cor.spearman,rmse,mae,cov.hpd,cov.equaltail,size.hpd,size.equaltail)

###################################################
### Full dataset (all covariates are available) ###
###################################################

system.time(sim <- NbBvs_pred(d=c(51:100), X = X, y = y, niter = 100000, burnin = 20000,
n.thin = 10, rho = 0.5, impute = FALSE))

med <- apply(sim,2,function(x){mcse.q(x,q=0.5)$est})
rmse <- sqrt(mean((med - true.y.pred)^2))
mae <- mean(abs(med - true.y.pred))
perc.5 <- apply(sim,2,function(x){mcse.q(x,q=0.05)$est})
perc.95 <- apply(sim,2,function(x){mcse.q(x,q=0.95)$est})
cov.equaltail <- mean(true.y.pred >= perc.5 & true.y.pred <= perc.95)
size.equaltail <- mean(perc.95 - perc.5 + 1)
cov.hpd <- mean(apply(rbind(true.y.pred,sim),2,function(x){x[1]\%in\%emp.hpd(x[-1])}))
size.hpd <- mean(apply(sim,2,function(x){length(emp.hpd(x))}))
cor.pearson <- cor(med,true.y.pred,method="pearson")
cor.spearman <- cor(med,true.y.pred,method="spearman")
scen1.full <- c(cor.pearson,cor.spearman,rmse,mae,cov.hpd,cov.equaltail,size.hpd,size.equaltail)

Note: this example is included for illustrative purposes.
To replicate the simulation in Li, Ghosh, and Villarini, change niter to 5,000,000.

}
\references{
\insertRef{Scot:Berg:2010}{NbBvs}

\insertRef{Li:2013}{NbBvs}
}
